@@ -1,5 +1,6 @@
 """ Contains all the data models used in inputs/outputs """
 
+from .add_group_user_request import AddGroupUserRequest
 from .architecture import Architecture
 from .auth_email_password_reset_token_request import AuthEmailPasswordResetTokenRequest
 from .auth_reset_password_request import AuthResetPasswordRequest
@@ -18,6 +19,7 @@ from .create_reservation_request import CreateReservationRequest
 from .dictionary import Dictionary
 from .edge import Edge
 from .endpoint import Endpoint
+from .endpoint_addresses import EndpointAddresses
 from .engagement_credentials import EngagementCredentials
 from .engagement_with_credentials import EngagementWithCredentials
 from .error import Error
@@ -25,11 +27,15 @@ from .family import Family
 from .filter import Filter
 from .find_available_reservations_response import FindAvailableReservationsResponse
 from .get_quilt_calibrations_response import GetQuiltCalibrationsResponse
+from .group import Group
 from .health import Health
 from .instruction_set_architecture import InstructionSetArchitecture
 from .internal_create_reservation_request import InternalCreateReservationRequest
+from .invite_user_request import InviteUserRequest
 from .list_client_applications_response import ListClientApplicationsResponse
 from .list_endpoints_response import ListEndpointsResponse
+from .list_group_users_response import ListGroupUsersResponse
+from .list_groups_response import ListGroupsResponse
 from .list_quantum_processors_response import ListQuantumProcessorsResponse
 from .list_reservations_response import ListReservationsResponse
 from .node import Node
@@ -39,6 +45,7 @@ from .order import Order
 from .parameter import Parameter
 from .parameter_spec import ParameterSpec
 from .quantum_processor import QuantumProcessor
+from .remove_group_user_request import RemoveGroupUserRequest
 from .reservation import Reservation
 from .translate_native_quil_to_encrypted_binary_request import TranslateNativeQuilToEncryptedBinaryRequest
 from .translate_native_quil_to_encrypted_binary_response import TranslateNativeQuilToEncryptedBinaryResponse
