@@ -16,6 +16,7 @@ class TranslateNativeQuilToEncryptedBinaryResponse:
     program: str
     memory_descriptors: Union[TranslateNativeQuilToEncryptedBinaryResponseMemoryDescriptors, Unset] = UNSET
     ro_sources: Union[Unset, List[List[str]]] = UNSET
+    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
     def to_dict(self, pick_by_predicate: Optional[Callable[[Any], bool]] = is_not_none) -> Dict[str, Any]:
         program = self.program
@@ -31,39 +32,64 @@ class TranslateNativeQuilToEncryptedBinaryResponse:
 
                 ro_sources.append(ro_sources_item)
 
-        dct = {
-            k: v
-            for k, v in {
+        field_dict: Dict[str, Any] = {}
+        field_dict.update(self.additional_properties)
+        field_dict.update(
+            {
                 "program": program,
-                "memoryDescriptors": memory_descriptors,
-                "roSources": ro_sources,
-            }.items()
-            if v != UNSET
-        }
+            }
+        )
+        if memory_descriptors is not UNSET:
+            field_dict["memoryDescriptors"] = memory_descriptors
+        if ro_sources is not UNSET:
+            field_dict["roSources"] = ro_sources
+
+        field_dict = {k: v for k, v in field_dict.items() if v != UNSET}
         if pick_by_predicate is not None:
-            dct = {k: v for k, v in dct.items() if pick_by_predicate(v)}
-        return dct
+            field_dict = {k: v for k, v in field_dict.items() if pick_by_predicate(v)}
+
+        return field_dict
 
     @staticmethod
-    def from_dict(d: Dict[str, Any]) -> "TranslateNativeQuilToEncryptedBinaryResponse":
-        program = d["program"]
+    def from_dict(src_dict: Dict[str, Any]) -> "TranslateNativeQuilToEncryptedBinaryResponse":
+        d = src_dict.copy()
+        program = d.pop("program")
 
         memory_descriptors: Union[TranslateNativeQuilToEncryptedBinaryResponseMemoryDescriptors, Unset] = UNSET
-        _memory_descriptors = d.get("memoryDescriptors")
+        _memory_descriptors = d.pop("memoryDescriptors", UNSET)
         if _memory_descriptors is not None and not isinstance(_memory_descriptors, Unset):
             memory_descriptors = TranslateNativeQuilToEncryptedBinaryResponseMemoryDescriptors.from_dict(
                 cast(Dict[str, Any], _memory_descriptors)
             )
 
         ro_sources = []
-        _ro_sources = d.get("roSources")
+        _ro_sources = d.pop("roSources", UNSET)
         for ro_sources_item_data in _ro_sources or []:
             ro_sources_item = cast(List[str], ro_sources_item_data)
 
             ro_sources.append(ro_sources_item)
 
-        return TranslateNativeQuilToEncryptedBinaryResponse(
+        translate_native_quil_to_encrypted_binary_response = TranslateNativeQuilToEncryptedBinaryResponse(
             program=program,
             memory_descriptors=memory_descriptors,
             ro_sources=ro_sources,
         )
+
+        translate_native_quil_to_encrypted_binary_response.additional_properties = d
+        return translate_native_quil_to_encrypted_binary_response
+
+    @property
+    def additional_keys(self) -> List[str]:
+        return list(self.additional_properties.keys())
+
+    def __getitem__(self, key: str) -> Any:
+        return self.additional_properties[key]
+
+    def __setitem__(self, key: str, value: Any) -> None:
+        self.additional_properties[key] = value
+
+    def __delitem__(self, key: str) -> None:
+        del self.additional_properties[key]
+
+    def __contains__(self, key: str) -> bool:
+        return key in self.additional_properties
